package
Version:
v0.0.0-...-a1b2d12
Opens a new window with list of versions in this module.
Published: May 4, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func PerformGETHTTPRequest(c *gin.Context, url string, requestBody interface{}, responseData interface{}) error
func PerformPOSTHTTPRequest(c *gin.Context, url string, requestBody interface{}, responseData interface{}) error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.